@@ -5,6 +5,7 @@ import (
 	"bytes"
 	"crypto/sha256"
 	"fmt"
+	"io"
 	"io/fs"
 	"path/filepath"
 	"regexp"
@@ -15,6 +16,9 @@ var (
 	// DefaultTemplateOptions are the default template options.
 	DefaultTemplateOptions = []string{"missingkey=error"}
 
+	// Break indicates that a walk should be stopped.
+	Break = io.EOF
+
 	// Skip indicates that entry should be skipped.
 	Skip = filepath.SkipDir
 
@@ -51,13 +55,13 @@ const (
 	Prefix = ".chezmoi"
 
 	RootName         = Prefix + "root"
+	VersionName      = Prefix + "version"
 	dataName         = Prefix + "data"
 	externalName     = Prefix + "external"
 	ignoreName       = Prefix + "ignore"
 	removeName       = Prefix + "remove"
 	scriptsDirName   = Prefix + "scripts"
 	templatesDirName = Prefix + "templates"
-	versionName      = Prefix + "version"
 )
 
 var (
@@ -80,7 +84,7 @@ var knownPrefixedFiles = newStringSet(
 	externalName+".yaml",
 	ignoreName,
 	removeName,
-	versionName,
+	VersionName,
 )
 
 var modeTypeNames = map[fs.FileMode]string{
