@@ -930,6 +930,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 		"chezmoi": map[string]interface{}{
 			"arch":         runtime.GOARCH,
 			"args":         os.Args,
+			"configFile":   c.configFileAbsPath.String(),
 			"executable":   executable,
 			"fqdnHostname": fqdnHostname,
 			"group":        group,
@@ -946,6 +947,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 				"date":    c.versionInfo.Date,
 				"version": c.versionInfo.Version,
 			},
+			"workingTree": c.WorkingTreeAbsPath.String(),
 		},
 	}
 }
@@ -1359,7 +1361,20 @@ func (c *Config) newSourceState(
 
 	sourceStateLogger := c.logger.With().Str(logComponentKey, logComponentValueSourceState).Logger()
 
-	sourceDirAbsPath, err := c.sourceDirAbsPath()
+	versionAbsPath := c.SourceDirAbsPath.JoinString(chezmoi.VersionName)
+	var minVersion *semver.Version
+	switch data, err := c.baseSystem.ReadFile(versionAbsPath); {
+	case errors.Is(err, fs.ErrNotExist):
+	case err != nil:
+		return nil, err
+	default:
+		minVersion, err = semver.NewVersion(strings.TrimSpace(string(data)))
+		if err != nil {
+			return nil, fmt.Errorf("%s: %w", versionAbsPath, err)
+		}
+	}
+
+	c.SourceDirAbsPath, err = c.sourceDirAbsPath()
 	if err != nil {
 		return nil, err
 	}
@@ -1373,9 +1388,10 @@ func (c *Config) newSourceState(
 		chezmoi.WithHTTPClient(httpClient),
 		chezmoi.WithInterpreters(c.Interpreters),
 		chezmoi.WithLogger(&sourceStateLogger),
+		chezmoi.WithMinVersion(minVersion),
 		chezmoi.WithMode(c.Mode),
 		chezmoi.WithPriorityTemplateData(c.Data),
-		chezmoi.WithSourceDir(sourceDirAbsPath),
+		chezmoi.WithSourceDir(c.SourceDirAbsPath),
 		chezmoi.WithSystem(c.sourceSystem),
 		chezmoi.WithTemplateFuncs(c.templateFuncs),
 		chezmoi.WithTemplateOptions(c.Template.Options),
