@@ -5,6 +5,8 @@ package cmd
 
 import (
 	"io"
+	"io/fs"
+	"syscall"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
@@ -17,3 +19,7 @@ var defaultInterpreters = make(map[string]*chezmoi.Interpreter)
 func enableVirtualTerminalProcessing(w io.Writer) error {
 	return nil
 }
+
+func fileInfoUID(info fs.FileInfo) int {
+	return int(info.Sys().(*syscall.Stat_t).Uid)
+}
